"use strict";
/**
 * @license
 * Copyright Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.setScriptSrc = exports.setScriptTextContent = void 0;
const resource_url_impl_js_1 = require("../../internals/resource_url_impl.js");
const script_impl_js_1 = require("../../internals/script_impl.js");
const window_js_1 = require("../globals/window.js");
/** Propagates CSP nonce to dynamically created scripts. */
function setNonceForScriptElement(script) {
    const nonce = (0, window_js_1.getScriptNonce)(script.ownerDocument);
    if (nonce) {
        script.setAttribute('nonce', nonce);
    }
}
/** Sets textContent from the given SafeScript. */
function setScriptTextContent(script, v, options) {
    script.textContent = (0, script_impl_js_1.unwrapScript)(v);
    if (options === null || options === void 0 ? void 0 : options.omitNonce)
        return;
    setNonceForScriptElement(script);
}
exports.setScriptTextContent = setScriptTextContent;
/** Sets the Src attribute using a TrustedResourceUrl */
function setScriptSrc(script, v, options) {
    script.src = (0, resource_url_impl_js_1.unwrapResourceUrl)(v);
    if (options === null || options === void 0 ? void 0 : options.omitNonce)
        return;
    setNonceForScriptElement(script);
}
exports.setScriptSrc = setScriptSrc;
