"use strict";
/**
 * @license
 * Copyright Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.setSvgUseHref = void 0;
const url_builders_js_1 = require("../../builders/url_builders.js");
require("../../environment/dev.js");
/**
 * Sets the Href attribute from the given URL.
 * javascript: and data: URL are blocked as they can lead to XSS and the <use>
 * element only loads resources same-origin.
 */
function setSvgUseHref(useEl, url) {
    const scheme = (0, url_builders_js_1.extractScheme)(url);
    if (scheme === 'javascript:' || scheme === 'data:') {
        if (process.env.NODE_ENV !== 'production') {
            const msg = `A URL with content '${url}' was sanitized away.`;
            console.error(msg);
        }
        return;
    }
    // Note that the href property is read-only, so setAttribute must be used.
    useEl.setAttribute('href', url);
}
exports.setSvgUseHref = setSvgUseHref;
