"use strict";
/**
 * @license
 * Copyright Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.documentExecCommand = exports.documentWrite = void 0;
const html_impl_js_1 = require("../../internals/html_impl.js");
/**
 * documentWrite safely calls {@link Document.write} on the given
 * {@link Document} with the given {@link SafeHtml}.
 */
function documentWrite(doc, text) {
    doc.write((0, html_impl_js_1.unwrapHtml)(text));
}
exports.documentWrite = documentWrite;
/**
 * Safely calls {@link Document.execCommand}. When command is insertHtml, a
 * SafeHtml must be passed in as value.
 */
function documentExecCommand(doc, command, value) {
    const commandString = String(command);
    let valueArgument = value;
    if (commandString.toLowerCase() === 'inserthtml') {
        valueArgument = (0, html_impl_js_1.unwrapHtml)(value);
    }
    return doc.execCommand(commandString, /* showUi= */ false, valueArgument);
}
exports.documentExecCommand = documentExecCommand;
