"use strict";
/**
 * @license
 * Copyright Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.locationAssign = exports.locationReplace = exports.setLocationHref = void 0;
const url_builders_js_1 = require("../../builders/url_builders.js");
/**
 * setLocationHref safely sets {@link Location.href} on the given
 * {@link Location} with given {@link Url}.
 */
function setLocationHref(loc, url) {
    const sanitizedUrl = (0, url_builders_js_1.unwrapUrlOrSanitize)(url);
    if (sanitizedUrl !== undefined) {
        loc.href = sanitizedUrl;
    }
}
exports.setLocationHref = setLocationHref;
/**
 * locationReplace safely calls {@link Location.replace} on the given
 * {@link Location} with given {@link Url}.
 */
function locationReplace(loc, url) {
    const sanitizedUrl = (0, url_builders_js_1.unwrapUrlOrSanitize)(url);
    if (sanitizedUrl !== undefined) {
        loc.replace(sanitizedUrl);
    }
}
exports.locationReplace = locationReplace;
/**
 * locationAssign safely calls {@link Location.assign} on the given
 * {@link Location} with given {@link Url}.
 */
function locationAssign(loc, url) {
    const sanitizedUrl = (0, url_builders_js_1.unwrapUrlOrSanitize)(url);
    if (sanitizedUrl !== undefined) {
        loc.assign(sanitizedUrl);
    }
}
exports.locationAssign = locationAssign;
