"use strict";
/**
 * @license
 * Copyright Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.unwrapStyleSheet = exports.isStyleSheet = exports.SafeStyleSheet = exports.unwrapScript = exports.isScript = exports.SafeScript = exports.EMPTY_SCRIPT = exports.unwrapResourceUrl = exports.isResourceUrl = exports.TrustedResourceUrl = exports.unwrapHtml = exports.isHtml = exports.SafeHtml = exports.EMPTY_HTML = exports.unwrapAttributePrefix = exports.SafeAttributePrefix = exports.safeStyleSheet = exports.concatStyleSheets = exports.valueAsScript = exports.safeScriptWithArgs = exports.safeScript = exports.concatScripts = exports.trustedResourceUrl = exports.toAbsoluteResourceUrl = exports.replaceParams = exports.replaceFragment = exports.objectUrlFromScript = exports.appendPathSegment = exports.appendParams = exports.ResourceUrlPolicyHintsType = exports.HtmlSanitizerBuilder = exports.CssSanitizerBuilder = exports.sanitizeHtmlToFragment = exports.sanitizeHtmlAssertUnchanged = exports.sanitizeHtml = exports.sanitizeHtmlWithCss = exports.scriptUrlToHtml = exports.scriptToHtml = exports.nodeToHtml = exports.joinHtmls = exports.htmlEscape = exports.doctypeHtml = exports.concatHtmls = exports.svgFragment = exports.htmlToNode = exports.htmlFragment = exports.safeAttrPrefix = void 0;
/** Safe builders */
var attribute_builders_js_1 = require("./builders/attribute_builders.js");
Object.defineProperty(exports, "safeAttrPrefix", { enumerable: true, get: function () { return attribute_builders_js_1.safeAttrPrefix; } });
var document_fragment_builders_js_1 = require("./builders/document_fragment_builders.js");
Object.defineProperty(exports, "htmlFragment", { enumerable: true, get: function () { return document_fragment_builders_js_1.htmlFragment; } });
Object.defineProperty(exports, "htmlToNode", { enumerable: true, get: function () { return document_fragment_builders_js_1.htmlToNode; } });
Object.defineProperty(exports, "svgFragment", { enumerable: true, get: function () { return document_fragment_builders_js_1.svgFragment; } });
var html_builders_js_1 = require("./builders/html_builders.js");
Object.defineProperty(exports, "concatHtmls", { enumerable: true, get: function () { return html_builders_js_1.concatHtmls; } });
Object.defineProperty(exports, "doctypeHtml", { enumerable: true, get: function () { return html_builders_js_1.doctypeHtml; } });
Object.defineProperty(exports, "htmlEscape", { enumerable: true, get: function () { return html_builders_js_1.htmlEscape; } });
Object.defineProperty(exports, "joinHtmls", { enumerable: true, get: function () { return html_builders_js_1.joinHtmls; } });
Object.defineProperty(exports, "nodeToHtml", { enumerable: true, get: function () { return html_builders_js_1.nodeToHtml; } });
Object.defineProperty(exports, "scriptToHtml", { enumerable: true, get: function () { return html_builders_js_1.scriptToHtml; } });
Object.defineProperty(exports, "scriptUrlToHtml", { enumerable: true, get: function () { return html_builders_js_1.scriptUrlToHtml; } });
var default_css_sanitizer_js_1 = require("./builders/html_sanitizer/default_css_sanitizer.js");
Object.defineProperty(exports, "sanitizeHtmlWithCss", { enumerable: true, get: function () { return default_css_sanitizer_js_1.sanitizeHtmlWithCss; } });
var html_sanitizer_js_1 = require("./builders/html_sanitizer/html_sanitizer.js");
Object.defineProperty(exports, "sanitizeHtml", { enumerable: true, get: function () { return html_sanitizer_js_1.sanitizeHtml; } });
Object.defineProperty(exports, "sanitizeHtmlAssertUnchanged", { enumerable: true, get: function () { return html_sanitizer_js_1.sanitizeHtmlAssertUnchanged; } });
Object.defineProperty(exports, "sanitizeHtmlToFragment", { enumerable: true, get: function () { return html_sanitizer_js_1.sanitizeHtmlToFragment; } });
var html_sanitizer_builder_js_1 = require("./builders/html_sanitizer/html_sanitizer_builder.js");
Object.defineProperty(exports, "CssSanitizerBuilder", { enumerable: true, get: function () { return html_sanitizer_builder_js_1.CssSanitizerBuilder; } });
Object.defineProperty(exports, "HtmlSanitizerBuilder", { enumerable: true, get: function () { return html_sanitizer_builder_js_1.HtmlSanitizerBuilder; } });
var resource_url_policy_js_1 = require("./builders/html_sanitizer/resource_url_policy.js");
Object.defineProperty(exports, "ResourceUrlPolicyHintsType", { enumerable: true, get: function () { return resource_url_policy_js_1.ResourceUrlPolicyHintsType; } });
var resource_url_builders_js_1 = require("./builders/resource_url_builders.js");
Object.defineProperty(exports, "appendParams", { enumerable: true, get: function () { return resource_url_builders_js_1.appendParams; } });
Object.defineProperty(exports, "appendPathSegment", { enumerable: true, get: function () { return resource_url_builders_js_1.appendPathSegment; } });
Object.defineProperty(exports, "objectUrlFromScript", { enumerable: true, get: function () { return resource_url_builders_js_1.objectUrlFromScript; } });
Object.defineProperty(exports, "replaceFragment", { enumerable: true, get: function () { return resource_url_builders_js_1.replaceFragment; } });
Object.defineProperty(exports, "replaceParams", { enumerable: true, get: function () { return resource_url_builders_js_1.replaceParams; } });
Object.defineProperty(exports, "toAbsoluteResourceUrl", { enumerable: true, get: function () { return resource_url_builders_js_1.toAbsoluteResourceUrl; } });
Object.defineProperty(exports, "trustedResourceUrl", { enumerable: true, get: function () { return resource_url_builders_js_1.trustedResourceUrl; } });
var script_builders_js_1 = require("./builders/script_builders.js");
Object.defineProperty(exports, "concatScripts", { enumerable: true, get: function () { return script_builders_js_1.concatScripts; } });
Object.defineProperty(exports, "safeScript", { enumerable: true, get: function () { return script_builders_js_1.safeScript; } });
Object.defineProperty(exports, "safeScriptWithArgs", { enumerable: true, get: function () { return script_builders_js_1.safeScriptWithArgs; } });
Object.defineProperty(exports, "valueAsScript", { enumerable: true, get: function () { return script_builders_js_1.valueAsScript; } });
var style_sheet_builders_js_1 = require("./builders/style_sheet_builders.js");
Object.defineProperty(exports, "concatStyleSheets", { enumerable: true, get: function () { return style_sheet_builders_js_1.concatStyleSheets; } });
Object.defineProperty(exports, "safeStyleSheet", { enumerable: true, get: function () { return style_sheet_builders_js_1.safeStyleSheet; } });
/** Types, constants and unwrappers */
var attribute_impl_js_1 = require("./internals/attribute_impl.js");
Object.defineProperty(exports, "SafeAttributePrefix", { enumerable: true, get: function () { return attribute_impl_js_1.SafeAttributePrefix; } });
Object.defineProperty(exports, "unwrapAttributePrefix", { enumerable: true, get: function () { return attribute_impl_js_1.unwrapAttributePrefix; } });
var html_impl_js_1 = require("./internals/html_impl.js");
Object.defineProperty(exports, "EMPTY_HTML", { enumerable: true, get: function () { return html_impl_js_1.EMPTY_HTML; } });
Object.defineProperty(exports, "SafeHtml", { enumerable: true, get: function () { return html_impl_js_1.SafeHtml; } });
Object.defineProperty(exports, "isHtml", { enumerable: true, get: function () { return html_impl_js_1.isHtml; } });
Object.defineProperty(exports, "unwrapHtml", { enumerable: true, get: function () { return html_impl_js_1.unwrapHtml; } });
var resource_url_impl_js_1 = require("./internals/resource_url_impl.js");
Object.defineProperty(exports, "TrustedResourceUrl", { enumerable: true, get: function () { return resource_url_impl_js_1.TrustedResourceUrl; } });
Object.defineProperty(exports, "isResourceUrl", { enumerable: true, get: function () { return resource_url_impl_js_1.isResourceUrl; } });
Object.defineProperty(exports, "unwrapResourceUrl", { enumerable: true, get: function () { return resource_url_impl_js_1.unwrapResourceUrl; } });
var script_impl_js_1 = require("./internals/script_impl.js");
Object.defineProperty(exports, "EMPTY_SCRIPT", { enumerable: true, get: function () { return script_impl_js_1.EMPTY_SCRIPT; } });
Object.defineProperty(exports, "SafeScript", { enumerable: true, get: function () { return script_impl_js_1.SafeScript; } });
Object.defineProperty(exports, "isScript", { enumerable: true, get: function () { return script_impl_js_1.isScript; } });
Object.defineProperty(exports, "unwrapScript", { enumerable: true, get: function () { return script_impl_js_1.unwrapScript; } });
var style_sheet_impl_js_1 = require("./internals/style_sheet_impl.js");
Object.defineProperty(exports, "SafeStyleSheet", { enumerable: true, get: function () { return style_sheet_impl_js_1.SafeStyleSheet; } });
Object.defineProperty(exports, "isStyleSheet", { enumerable: true, get: function () { return style_sheet_impl_js_1.isStyleSheet; } });
Object.defineProperty(exports, "unwrapStyleSheet", { enumerable: true, get: function () { return style_sheet_impl_js_1.unwrapStyleSheet; } });
