/**
 * @license
 * Copyright Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
import { unwrapResourceUrl, } from '../../internals/resource_url_impl.js';
import { unwrapScript } from '../../internals/script_impl.js';
import { getScriptNonce } from '../globals/window.js';
/** Propagates CSP nonce to dynamically created scripts. */
function setNonceForScriptElement(script) {
    const nonce = getScriptNonce(script.ownerDocument);
    if (nonce) {
        script.setAttribute('nonce', nonce);
    }
}
/** Sets textContent from the given SafeScript. */
export function setScriptTextContent(script, v, options) {
    script.textContent = unwrapScript(v);
    if (options === null || options === void 0 ? void 0 : options.omitNonce)
        return;
    setNonceForScriptElement(script);
}
/** Sets the Src attribute using a TrustedResourceUrl */
export function setScriptSrc(script, v, options) {
    script.src = unwrapResourceUrl(v);
    if (options === null || options === void 0 ? void 0 : options.omitNonce)
        return;
    setNonceForScriptElement(script);
}
