/**
 * @license
 * Copyright Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
import { unwrapHtml } from '../../internals/html_impl.js';
/**
 * documentWrite safely calls {@link Document.write} on the given
 * {@link Document} with the given {@link SafeHtml}.
 */
export function documentWrite(doc, text) {
    doc.write(unwrapHtml(text));
}
/**
 * Safely calls {@link Document.execCommand}. When command is insertHtml, a
 * SafeHtml must be passed in as value.
 */
export function documentExecCommand(doc, command, value) {
    const commandString = String(command);
    let valueArgument = value;
    if (commandString.toLowerCase() === 'inserthtml') {
        valueArgument = unwrapHtml(value);
    }
    return doc.execCommand(commandString, /* showUi= */ false, valueArgument);
}
