/**
 * @license
 * Copyright Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
import { TrustedResourceUrl } from '../../internals/resource_url_impl.js';
/**
 * WorkerGlobalScopeWithImportScripts is an {@link WindowOrWorkerGlobalScope}
 * that also has {@link WorkerGlobalScope.importScripts} as
 * {@link WorkerGlobalScope} in some cases cannot be depended on directly.
 */
export interface WorkerGlobalScopeWithImportScripts extends WindowOrWorkerGlobalScope {
    importScripts: (...url: string[]) => void;
}
/**
 * Safely creates a Web Worker.
 *
 * Example usage:
 *   const trustedResourceUrl = trustedResourceUrl`/safe_script.js`;
 *   createWorker(trustedResourceUrl);
 * which is a safe alternative to
 *   new Worker(url);
 * The latter can result in loading untrusted code.
 */
export declare function createWorker(url: TrustedResourceUrl, options?: {}): Worker;
/** Safely creates a shared Web Worker. */
export declare function createSharedWorker(url: TrustedResourceUrl, options?: string | WorkerOptions): SharedWorker;
/** Safely calls importScripts */
export declare function workerGlobalScopeImportScripts(scope: WorkerGlobalScopeWithImportScripts, ...urls: TrustedResourceUrl[]): void;
